"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processor = void 0;
const metadataProcessor_1 = require("./metadataProcessor");
const blocks_1 = require("./blocks");
const processor = async (blocks, actions, getCache, createNodeId, reporter, cache) => {
    const { thumbnail, tableOfContents, updatedBlocks, rawText } = await processBlocksForContent(blocks, actions, getCache, createNodeId, reporter, cache);
    await (0, metadataProcessor_1.processMetadata)(blocks, actions, createNodeId, reporter, cache);
    return [thumbnail, tableOfContents, updatedBlocks, rawText];
};
exports.processor = processor;
const processBlocksForContent = async (blocks, actions, getCache, createNodeId, reporter, cache) => {
    const context = {
        actions,
        getCache,
        createNodeId,
        reporter,
        cache,
    };
    // 블록 프로세서 레지스트리 생성
    const processorRegistry = new blocks_1.BlockProcessorRegistry(context);
    const tableOfContents = [];
    let thumbnail = null;
    let rawText = "";
    const updatedBlocks = [];
    // 첫 번째 이미지 블록을 찾아 썸네일로 사용
    let firstImageIndex = blocks.findIndex((block) => block.type === "image");
    // 블록 처리
    const processResults = await Promise.all(blocks.map(async (block, index) => {
        const result = await processorRegistry.processBlock(block);
        // 썸네일 처리
        if (index === firstImageIndex && result.thumbnail) {
            thumbnail = result.thumbnail;
        }
        // 텍스트 데이터 추가
        if (result.plainText) {
            rawText += result.plainText + " ";
        }
        // 목차 데이터 추가
        if (result.tableOfContents) {
            tableOfContents.push(...result.tableOfContents);
        }
        return result;
    }));
    // 업데이트된 블록 적용
    processResults.forEach((result, index) => {
        if (result.updatedBlock) {
            updatedBlocks[index] = result.updatedBlock;
        }
        else {
            updatedBlocks[index] = blocks[index];
        }
    });
    return { thumbnail, tableOfContents, updatedBlocks, rawText };
};
